package jcg.zheng.testngdemo;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

import java.time.Duration;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.support.ui.Select;
import org.openqa.selenium.support.ui.WebDriverWait;

public class SeleniumDropDownTest {

	private static final String CHROME_DRIVER_PATH = "C:\\Users\\azpm0\\Mary\\devTools\\chromedriver-win64\\chromedriver.exe";

	private static final String SELECT_WEB_NAME = "demoSelectName";

	private static final String SELECTED_OPTION_TEXT = "Option Text 1";

	private static final String SELECTED_OPTION_VALUE = "opt1";

	protected static final String URL_WITH_DROPDOWN = "file:///C:/MaryTools/workspace/selenium-example/src/web/selectDemo.html";

	private static final String WEBDRIVER_CHROME_DRIVER = "webdriver.chrome.driver";

	protected WebDriver driver;

	private WebElement questionDropdownbox;

	protected WebDriverWait webdriverwait;

	@AfterEach
	public void cleanup() {
		driver.close();
		driver.quit();
	}

	@Test
	public void print_dropdown_options() {
		Select dropdown = new Select(questionDropdownbox);

		dropdown.getOptions().stream().forEach(opt -> System.out
				.println("Option value=" + opt.getAttribute("value") + ", option Label=" + opt.getText()));

	}

	@Test
	public void select_dropdown_element_byIndex() {
		Select dropdown = new Select(questionDropdownbox);

		dropdown.selectByIndex(0);

		WebElement firstSelectedOpt = dropdown.getFirstSelectedOption();
		assertEquals(SELECTED_OPTION_VALUE, firstSelectedOpt.getAttribute("value"));

	}

	@Test
	public void select_dropdown_element_byText() {
		Select dropdown = new Select(questionDropdownbox);

		dropdown.selectByVisibleText(SELECTED_OPTION_TEXT);

		WebElement firstSelectedOpt = dropdown.getFirstSelectedOption();
		assertEquals(SELECTED_OPTION_VALUE, firstSelectedOpt.getAttribute("value"));

	}

	@Test
	public void select_dropdown_element_byValue() {
		Select dropdown = new Select(questionDropdownbox);

		dropdown.selectByValue(SELECTED_OPTION_VALUE);

		WebElement firstSelectedOpt = dropdown.getFirstSelectedOption();
		assertEquals(SELECTED_OPTION_VALUE, firstSelectedOpt.getAttribute("value"));

	}

	@BeforeEach
	public void setupWebDriver() {
		System.setProperty(WEBDRIVER_CHROME_DRIVER, CHROME_DRIVER_PATH);

		driver = new ChromeDriver();

		driver.manage().deleteAllCookies();
		driver.manage().window().maximize();
		driver.manage().timeouts().pageLoadTimeout(Duration.ofMinutes(1));
		driver.manage().timeouts().implicitlyWait(Duration.ofMinutes(1));
		driver.get(URL_WITH_DROPDOWN);

		questionDropdownbox = driver.findElement(By.name(SELECT_WEB_NAME));
		assertTrue(questionDropdownbox.isDisplayed());

	}

}
